==> haskell-hspec-2.11.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.11.1
visibility:           public
id:                   hspec-2.11.1-GIH8vH53bMNE8dUYSTqrgH
key:                  hspec-2.11.1-GIH8vH53bMNE8dUYSTqrgH
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  1f75bc008d2eaf0b8dad3f849b77592a
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.11.1-GIH8vH53bMNE8dUYSTqrgH
depends:
    QuickCheck-2.15.0.1-KEw9aoMxM6q6i8cfYYug2V base-4.17.2.1
    hspec-core-2.11.1-FEtocjFrEnV9tzCy4gGXD9
    hspec-discover-2.11.1-J9FgaXIOftcJiOZVh13TNv
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.11.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.11.1
visibility:           public
id:                   hspec-2.11.1-IdJoh4JqLqi36U3zxarxk3
key:                  hspec-2.11.1-IdJoh4JqLqi36U3zxarxk3
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  4acc1233194bb9d805802f0aa7712a77
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.11.1-IdJoh4JqLqi36U3zxarxk3
depends:
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE base-4.17.2.1
    hspec-core-2.11.1-EEUB5Tel7FBJZKJ4IZlh7F
    hspec-discover-2.11.1-57xjMPpDfOGB1dqEz9o96d
    hspec-expectations-0.8.3-HoU1SHmaxn0CpyNDindE4g

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
